# Strutta Container
module Strutta
  # @abstract
  # APIObject contains all the HTTP request methods
  class APIObject
    attr_accessor :game

    # GET index request
    # (Uses instance vars of child object to generate resource path)
    #
    # @return [Hash] Parsed body of the API response
    def all(params = {})
      @game.verify_no_id(@id)
      @game.all(params, "#{@game.id}/#{@root_path}")
    end

    # POST request
    # (Uses instance vars of child object to generate resource path)
    #
    # @return [Hash] Parsed body of the API response
    def create(params = {})
      @game.verify_no_id(@id)
      @game.create(params, "#{@game.id}/#{@root_path}")
    end

    # GET request
    # (Uses instance vars of child object to generate resource path)
    #
    # @return [Hash] Parsed body of the API response
    def get(params = {})
      @game.verify_id(@id, Errors::ROUND_ID_REQUIRED)
      @game.get(params, @root_path)
    end

    # PATCH request
    # (Uses instance vars of child object to generate resource path)
    #
    # @return [Hash] Parsed body of the API response
    def update(params = {})
      @game.verify_id(@id, Errors::ROUND_ID_REQUIRED)
      @game.update(params, @root_path)
    end

    # DELETE request
    # (Uses instance vars of child object to generate resource path)
    #
    # @return [Hash] Parsed body of the API response
    def delete
      @game.verify_id(@id, Errors::ROUND_ID_REQUIRED)
      @game.delete(@root_path)
    end

    # Manually disable a method in child classed
    def method_disabled(*_)
      fail Errors::DisabledEndpointError, Errors::METHOD_DISABLED
    end
  end
end
